2024-03-26 Version: 3.0.1
- Update API DescribeExpressConnectRouterChildInstance: update response param.


2024-03-22 Version: 3.0.0
- Update API DescribeExpressConnectRouterAllowedPrefixHistory: add param AssociationId.
- Update API DescribeExpressConnectRouterAllowedPrefixHistory: delete param AssociatonId.


2024-03-19 Version: 2.0.0
- Delete API GetExpressConnectRouter.


2024-03-12 Version: 1.0.0
- Generated python 2023-09-01 for ExpressConnectRouter.

